package de.donmanfred;

import com.google.firebase.database.Query;
import anywheresoftware.b4a.AbsObjectWrapper;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.ShortName;

@ShortName("Query")
//@Permissions(values={"android.permission.INTERNET", "android.permission.ACCESS_NETWORK_STATE"})
//@Events(values={"onSigned(sign As Object)"})
//@DependsOn(values={"com.android.support:support-v4"})

/**
 * com.android.support:support-v4
 * com.android.support:appcompat-v7
 * com.android.support:cardview-v7
 * com.android.support:gridlayout-v7
 * com.android.support:mediarouter-v7
 * com.android.support:palette-v7
 * com.android.support:recyclerview-v
 * com.android.support:preference-v7
 * com.android.support:support-v13
 */

public class QueryWrapper extends AbsObjectWrapper<Query> {
	private BA ba;

	/**
	 * The Query class (and its subclass, DatabaseReference) are 
	 * used for reading data. Listeners are attached, and they will 
	 * be triggered when the corresponding data changes.
	 * 
	 * Instances of Query are obtained by calling startAt(), 
	 * endAt(), or limit() on a DatabaseReference. 
	 */
	public void Initialize(final BA ba, Query qry) {
		this.ba = ba;

		final Query _obj = qry;
		setObject(_obj);
	}

  /**
   * By calling `keepSynced(true)` on a location, the data for that 
   * location will automatically be downloaded and kept in sync, 
   * even when no listeners are attached for that location.
   */
  public void keepSynced(boolean keepSynced){
		getObject().keepSynced(keepSynced);
	}

	
	/**
	 * Create a query constrained to only return child nodes 
	 * with a value less than or equal to the given value, 
	 * using the given orderBy directive or priority as 
	 * default, and additionally only child nodes with a 
	 * key less than or equal to the given key.
	 */
	public QueryWrapper endAtBool(boolean value, String key){
		getObject().endAt(value, key);
		return this;
	}
	/**
	 * Create a query constrained to only return child nodes 
	 * with a value less than or equal to the given value, 
	 * using the given orderBy directive or priority as default.
	 */
	public QueryWrapper endAtBool2(boolean value){
		getObject().endAt(value);
		return this;
	}

	/**
	 * Create a query constrained to only return child nodes 
	 * with a value less than or equal to the given value, 
	 * using the given orderBy directive or priority as 
	 * default, and additionally only child nodes with a 
	 * key less than or equal to the given key.
	 */
	public QueryWrapper endAtDouble(double value, String key){
		getObject().endAt(value, key);
		return this;
	}
	/**
	 * Create a query constrained to only return child nodes 
	 * with a value less than or equal to the given value, 
	 * using the given orderBy directive or priority as default.
	 */
	public QueryWrapper endAtDouble2(double value){
		getObject().endAt(value);
		return this;
	}

	/**
	 * Create a query constrained to only return child nodes 
	 * with a value less than or equal to the given value, 
	 * using the given orderBy directive or priority as 
	 * default, and additionally only child nodes with a 
	 * key key less than or equal to the given key. 
	 */
	public QueryWrapper endAtString(String value, String key){
		getObject().endAt(value, key);
		return this;
	}
	/**
	 * Create a query constrained to only return child nodes 
	 * with a value less than or equal to the given value, 
	 * using the given orderBy directive or priority as default.
	 */
	public QueryWrapper endAtString2(String value){
		getObject().endAt(value);
		return this;
	}

	/**
	 * Create a query with limit and anchor it 
	 * to the end of the window
	 */
	public QueryWrapper LimitToLast(int count){
		getObject().limitToLast(count);
		return this;
	}
	
	/**
	 * Create a query with limit and anchor 
	 * it to the start of the window
	 */
	public QueryWrapper LimitToFirst(int count){
		getObject().limitToFirst(count);
		return this;
	}

	/**
	 * Create a query in which child nodes are 
	 * ordered by the values of the specified path.
	 */
	public QueryWrapper orderByChild(String child){
		getObject().orderByChild(child);
		return this;
	}
	/**
	 * Create a query in which child nodes are 
	 * ordered by their keys.
	 */
	public QueryWrapper orderByKey(){
		getObject().orderByKey();
		return this;
	}
	
	/**
	 * Create a query in which child nodes are 
	 * ordered by their priorities.
	 */
	public QueryWrapper orderByPriority(){
		getObject().orderByPriority();
		return this;
	}
	
	/**
	 * Create a query in which nodes are 
	 * ordered by their value
	 */
	public QueryWrapper orderByValue(){
		getObject().orderByValue();
		return this;
	}

	public Query query(){
		return getObject();
	}

	
	
}
